@@ -1,13 +1,17 @@
-# $Id: Datatype.pm 1185 2009-08-13 11:36:46Z maj1 $
+# $Id: Datatype.pm 1247 2010-03-04 15:47:17Z rvos $
 package Bio::Phylo::Matrices::Datatype;
-use Bio::Phylo::Util::XMLWritable;
+use Bio::Phylo::NeXML::Writable ();
 use Bio::Phylo::Factory;
 use Bio::Phylo::Util::Exceptions 'throw';
-use Bio::Phylo::Util::CONSTANT qw'_DOMCREATOR_ looks_like_hash';
-use UNIVERSAL 'isa';
+use Bio::Phylo::Util::CONSTANT qw(
+	_DOMCREATOR_ 
+	looks_like_hash 
+	looks_like_instance 
+	looks_like_implementor
+);
 use strict;
 use vars '@ISA';
-@ISA = qw(Bio::Phylo::Util::XMLWritable);
+@ISA = qw(Bio::Phylo::NeXML::Writable);
 
 {
     
@@ -68,7 +72,7 @@ Datatype constructor.
         }
         my $typeclass = __PACKAGE__ . '::' . $type;
         my $self      = __PACKAGE__->SUPER::new( '-tag' => 'states' ); 
-        eval "require $typeclass";
+        eval "require $typeclass"; 
         if ( $@ ) {
         	throw 'BadFormat' => "'$type' is not a valid datatype";
         }
@@ -82,7 +86,7 @@ Datatype constructor.
         my $self  = shift;
         my ( $lookup, $missing, $gap );
         {
-            no strict 'refs';
+            no strict 'refs'; 
             $lookup  = ${ $class . '::LOOKUP'  };
             $missing = ${ $class . '::MISSING' }; 
             $gap     = ${ $class . '::GAP'     };
@@ -118,7 +122,7 @@ Datatype constructor.
 			if ( $@ and not ref $@ and $@ =~ m/^Can't locate object method/ ) {
 				throw 'UnknownMethod' => "Processing argument '$key' as method '$mutator' failed: $@";
 			}
-			elsif ( UNIVERSAL::isa( $@, 'Bio::Phylo::Util::Exceptions') ) {
+			elsif ( looks_like_instance $@, 'Bio::Phylo::Util::Exceptions' ) {
 				$@->rethrow;
 			}
 		}         
@@ -156,7 +160,7 @@ Sets state lookup table.
         
         # we have a value
         if ( defined $lookup ) {
-            if ( UNIVERSAL::isa( $lookup, 'HASH' ) ) {
+            if ( looks_like_instance $lookup, 'HASH' ) {
                 $lookup{$id} = $lookup;
             }
             else {
@@ -406,7 +410,7 @@ Gets state lookup table.
            my $class = ref $self;
            my $lookup;
            {
-                no strict 'refs';
+                no strict 'refs'; 
                 $lookup = ${ $class . '::LOOKUP'  };
                 use strict;
            }
@@ -478,10 +482,10 @@ Validates argument.
         my $self = shift;        
         my @data;
         for my $arg ( @_ ) {
-        	if ( UNIVERSAL::can( $arg, 'get_char') ) {
+        	if ( looks_like_implementor $arg, 'get_char' ) {
         		push @data, $arg->get_char;
         	}
-        	elsif ( UNIVERSAL::isa( $arg, 'ARRAY') ) {
+        	elsif ( looks_like_instance $arg, 'ARRAY' ) {
         		push @data, @{ $arg };
         	}
         	else {
@@ -762,11 +766,11 @@ Analog to to_xml.
 		my $dom = $_[0];
 		my @args = @_;
 		# handle dom factory object...
-		if ( isa($dom, 'SCALAR') && $dom->_type == _DOMCREATOR_ ) {
+		if ( looks_like_instance($dom, 'SCALAR') && $dom->_type == _DOMCREATOR_ ) {
 		    splice(@args, 0, 1);
 		}
 		else {
-		    $dom = $Bio::Phylo::Util::DOM::DOM;
+		    $dom = $Bio::Phylo::NeXML::DOM::DOM;
 		    unless ($dom) {
 			throw 'BadArgs' => 'DOM factory object not provided';
 		    }
@@ -806,20 +810,20 @@ Analog to to_xml.
 		    my $special = $self->get_ids_for_special_symbols;
 		    if ( %{ $special } ) {
 				my $uss;
-				$uss = $dom->create_element('uncertain_state_set');
+				$uss = $dom->create_element('-tag'=>'uncertain_state_set');
 				$uss->set_attributes( 'id' => 's'.$special->{$gap} );
 				$uss->set_attributes( 'symbol' => '-' );
 				$elt->set_child($uss);
-				$uss = $dom->create_element('uncertain_state_set');
+				$uss = $dom->create_element('-tag'=>'uncertain_state_set');
 				$uss->set_attributes( 'id' => 's'.$special->{$missing} );
 				$uss->set_attributes( 'symbol' => '?' );
 				my $mbr;
 				for (@states) {
-				    $mbr = $dom->create_element('member');
+				    $mbr = $dom->create_element('-tag'=>'member');
 				    $mbr->set_attributes( 'state' => $id_for_state->{$_} );
 				    $uss->set_child($mbr);
 				}
-				$mbr = $dom->create_element('member');
+				$mbr = $dom->create_element('-tag'=>'member');
 				$mbr->set_attributes( 'state' => 's'.$special->{$gap} );
 				$uss->set_child($mbr);
 				$elt->set_child($uss);
@@ -840,11 +844,11 @@ Analog to to_xml.
 	        if ( scalar @mapping > 1 ) {
 	            my $tag = $polymorphism ? 'polymorphic_state_set' : 'uncertain_state_set';
 	
-			    $elt = $dom->create_element($tag);
+			    $elt = $dom->create_element('-tag'=>$tag);
 			    $elt->set_attributes( 'id' => $state_id );
 			    $elt->set_attributes( 'symbol' => $symbol );
 	            for my $map ( @mapping ) {
-					my $mbr = $dom->create_element('member');
+					my $mbr = $dom->create_element('-tag'=>'member');
 					$mbr->set_attributes('state' => $id_for_state->{ $map } );
 					$elt->set_child($mbr);
 	            }
@@ -853,7 +857,7 @@ Analog to to_xml.
 	        
 	        # no ambiguity
 	        else {
-		    $elt = $dom->create_element('state');
+		    $elt = $dom->create_element('-tag'=>'state');
 		    $elt->set_attributes( 'id' => $state_id );
 		    $elt->set_attributes( 'symbol' => $symbol ); 
 	        }
@@ -883,7 +887,7 @@ Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
 =head1 REVISION
 
- $Id: Datatype.pm 1185 2009-08-13 11:36:46Z maj1 $
+ $Id: Datatype.pm 1247 2010-03-04 15:47:17Z rvos $
 
 =cut
 
